////////////////////////////////////////////////////////////////////////////
// Rev: 2010.1 (P4JsApi 1.0 Example)
//
// NOTE: This is an example only, and should be modified to work in
// a production environment! No warranty is expressed or implied.
// Scripts should be tested thoroughly on a test server before
// using in a production environment.
//
////////////////////////////////////////////////////////////////////////////
// Copyright (c) 2010, Perforce Software, Inc.  All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
//
// 1.  Redistributions of source code must retain the above copyright
//     notice, this list of conditions and the following disclaimer.
//
// 2.  Redistributions in binary form must reproduce the above copyright
//     notice, this list of conditions and the following disclaimer in the
//     documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
// AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
// IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
// ARE DISCLAIMED. IN NO EVENT SHALL PERFORCE SOFTWARE, INC. BE LIABLE FOR ANY
// DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
// LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
// ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
////////////////////////////////////////////////////////////////////////////

var P4 = P4 || {};
P4.createUsersWidget = function() {
    try {
        var userData = [];
        var userStore = new Ext.data.ArrayStore({
            fields: [
            {
                name: 'user'
            },
            {
                name: 'name'
            }
            ]
        });
        P4JsApi.p4("users",

        function(users) {
            var user = 0;
            while (users.data[user]) {
                userData.push([users.data[user].User, users.data[user].FullName]);
                user++;
            }
            userStore.loadData(userData);
        });

        var userGrid = null;
        var spotlightHandler = function() {
            var selected = userGrid.getSelectionModel().getSelected();
            if (selected && selected.get('user')) {
                P4.showSpotlight(selected.get('user'));
            } else {
                alert("You must select a user first!");
            }
        }

        userGrid = new Ext.grid.GridPanel({
            store: userStore,
            columns: [
            {
                id: 'user',
                header: 'User',
                width: 50,
                sortable: true,
                dataIndex: 'user'
            },
            {
                id: 'name',
                header: 'Full Name',
                width: 50,
                sortable: true,
                dataIndex: 'name'
            },
            ],
            stripeRows: true,
            width: 200,
            title: 'Users',
            autoExpandColumn: 'name',
            border: false,
            autoScroll: true,
            iconCls: 'silk-user',
            viewConfig: {
                forceFit: true,
            },
            tbar: [{
                id: 'spotlight1',
                iconCls: 'silk-user-comment',
                text: "User spotlight",
                handler: spotlightHandler
            }],
        });
        return userGrid;
    } catch(e) {
        alert(e);
    }
}